@@ -26,7 +26,6 @@ class TestDOMNode (TestCase):
         self.assertEqual(DOM_DOCUMENT_POSITION_CONTAINED_BY, 16)
         self.assertEqual(DOM_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC, 32)
 
-
     def testMethods(self):
         self.assertResultIsBOOL(DOMNode.hasChildNodes)
         self.assertArgIsBOOL(DOMNode.cloneNode_, 0)
@@ -38,5 +37,13 @@ class TestDOMNode (TestCase):
 
         self.assertResultIsBOOL(DOMNode.isContentEditable)
 
+    @min_os_level('10.5')
+    def testMethods10_5(self):
+        self.assertResultIsBOOL(DOMNode.isDefaultNamespace_)
+
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(DOMNode.contains_)
+
 if __name__ == "__main__":
     main()
