@@ -1,5 +1,6 @@
 from PyObjCTools.TestSupport import *
 from WebKit import *
+import sys
 
 class TestWKWebViewConfiguration (TestCase):
     @onlyOn64Bit
@@ -14,5 +15,16 @@ class TestWKWebViewConfiguration (TestCase):
         self.assertResultIsBOOL(WKWebViewConfiguration.allowsAirPlayForMediaPlayback)
         self.assertArgIsBOOL(WKWebViewConfiguration.setAllowsAirPlayForMediaPlayback_, 0)
 
+    def testConstants(self):
+        self.assertEqual(WKUserInterfaceDirectionPolicyContent, 0)
+        self.assertEqual(WKUserInterfaceDirectionPolicySystem, 1)
+
+        self.assertEqual(WKAudiovisualMediaTypeNone, 0)
+        self.assertEqual(WKAudiovisualMediaTypeAudio, 1 << 0)
+        self.assertEqual(WKAudiovisualMediaTypeVideo, 1 << 1)
+        self.assertEqual(WKAudiovisualMediaTypeAll, sys.maxsize * 2 + 1)
+
+
+
 if __name__ == "__main__":
     main()
